@@ -18,12 +18,14 @@ public:
     QRegExp urlPattern() const;
     bool urlSupported(const QUrl &url) const;
     void checkUrl(const QUrl &url);
-    void getDownloadUrl(const QUrl &url);
+    void getDownloadRequest(const QUrl &url);
     inline bool loginSupported() const { return true; }
     void login(const QString &username, const QString &password);
     inline bool recaptchaRequired() const { return true; }
     inline QString recaptchaKey() const { return m_captchaKey; }
-    inline QString recaptchaServiceName() const { return QString("SolveMedia"); }
+    inline QString recaptchaServiceName() const { return m_captchaService; }
+    inline int maximumConnections() const { return 0; }
+    bool cancelCurrentOperation();
 
 public slots:
     void submitCaptchaResponse(const QString &challenge, const QString &response);
@@ -38,8 +40,13 @@ private slots:
     void onWebPageDownloaded();
     void onCaptchaSubmitted();
 
+signals:
+    void currentOperationCancelled();
+
 private:
     QUrl m_url;
+    QUrl m_captchaUrl;
+    QString m_captchaService;
     QString m_captchaKey;
 };
 
